pub struct AuthenticatedParams<'a> { /* private fields */ }Implementations
Sourceimpl<'a> AuthenticatedParams<'a>
impl<'a> AuthenticatedParams<'a>
Sourcepub fn prepare(
keypair: &Keypair,
id: &Id<'_>,
method: &str,
params: Option<Cow<'a, RawValue>>,
now: u64,
) -> Self
pub fn prepare( keypair: &Keypair, id: &Id<'_>, method: &str, params: Option<Cow<'a, RawValue>>, now: u64, ) -> Self
Prepare authenticated params at a given timestamp.
Sourcepub fn prepare_now(
keypair: &Keypair,
id: &Id<'a>,
method: &'a str,
params: Option<Cow<'a, RawValue>>,
) -> Result<Self, Error>
pub fn prepare_now( keypair: &Keypair, id: &Id<'a>, method: &'a str, params: Option<Cow<'a, RawValue>>, ) -> Result<Self, Error>
Prepare authenticated params using the current SystemTime.
Errors
This function will return an error if current timpestamp generation fails.
Sourcepub fn verify<VT: VerifyTimestamp>(
self,
id: &Id<'_>,
method: &str,
verify_timestamp: &VT,
) -> Result<VerifiedParams<'a>, Error>
pub fn verify<VT: VerifyTimestamp>( self, id: &Id<'_>, method: &str, verify_timestamp: &VT, ) -> Result<VerifiedParams<'a>, Error>
Verify authenticated params at a given timestamp.
Errors
This function will return an error if the signature or timestamp verification fails.